@@ -410,6 +410,7 @@ sub deliver {
 	my $contact = ( $user =~m{([^<>\@\s]+)\@} ? $1 : $user ).
 	    "\@$addr";
 	$contact = $proto.':'.$contact if $contact !~m{^\w+:};
+	$contact = "<$contact>" if $contact =~m{;};
 	$packet->insert_header( contact => $contact );
     }
     if ( $need_allow && ! ( my @a = $packet->get_header( 'allow' ))) {
@@ -537,9 +538,8 @@ sub via_branch {
 	push @parts,
 	    ( sort $packet->get_header('proxy-require')),
 	    $packet->get_header('route'),
-	    $packet->get_header('to'),
 	    $packet->get_header('from'),
-	    ($packet->as_parts())[1];
+	    ($packet->as_parts())[1]; # URI
 	$val .= substr(md5_hex(@parts),0,15);
     }
     return $val;
@@ -584,7 +584,9 @@ sub can_deliver_to {
 sub match {
     my Net::SIP::Leg $self = shift;
     my $args = shift;
-    return if $args->{addr}  && $args->{addr}  ne $self->{src}{addr};
+    return if $args->{addr}
+	&& $args->{addr} ne $self->{src}{addr}
+	&& $args->{addr} ne $self->{src}{host};
     return if $args->{port}  && $args->{port}  != $self->{src}{port};
     return if $args->{proto} && $args->{proto} ne $self->{proto};
     return if $args->{sub}   && !invoke_callback($args->{sub},$self);
