@@ -29,11 +29,12 @@ BEGIN {
     }) {
 	$mod6 = 'IO::Socket::IP';
 	*INETSOCK = sub {
-	    my %args = @_;
+	    return IO::Socket::IP->new(@_) if @_ == 1;
 	    # Hack to work around the problem that IO::Socket::IP defaults to
 	    # AI_ADDRCONFIG which creates problems if we have only the loopback
 	    # interface. If we already know the family this flag is more harmful
 	    # then useful.
+	    my %args = @_;
 	    $args{GetAddrInfoFlags} = 0  if ! defined $args{GetAddrInfoFlags}
 		and $args{Domain} || $args{Family};
 	    return IO::Socket::IP->new(%args);
@@ -188,7 +189,7 @@ sub sip_parts2hdrval {
 	my $v = $param->{$k};
 	if ( defined $v ) {
 	    # escape special chars
-	    $v =~s{([%\r\n\t"[:^print:]])}{ sprintf "%%%02x",ord($1) }sg;
+	    $v =~s{([%\r\n\t"[:^print:]])}{ sprintf "%%%02x",ord($1) }esg;
 	    $v = '"'.$v.'"' if $v =~m{\s|$delim};
 	    $val .= '='.$v
 	}
